#
# spec file for package coreos-installer
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           coreos-installer
Version:        0.24.0
Release:        1.1
Summary:        Installer for CoreOS disk images
License:        Apache-2.0
URL:            https://github.com/openshift/coreos-installer
Source0:        coreos-installer-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  cargo >= 1.76
BuildRequires:  cargo-packaging
BuildRequires:  gnupg
BuildRequires:  libzstd-devel
BuildRequires:  openssl-devel

%description
coreos-installer is a program to assist with installing Fedora CoreOS (FCOS) and
Red Hat Enterprise Linux CoreOS (RHCOS). It can do the following:

* Install the operating system to a target disk, optionally customizing it with
  an Ignition config or first-boot kernel parameters (coreos-installer install)
* Download and verify an operating system image for various cloud,
  virtualization, or bare metal platforms (coreos-installer download)
* List Fedora CoreOS images available for download
  (coreos-installer list-stream)
* Embed an Ignition config in a live ISO image to customize the running system
  that boots from it (coreos-installer iso ignition)
* Wrap an Ignition config in an initrd image that can be appended to the live
* PXE initramfs to customize the running system that boots from it
  (coreos-installer pxe ignition)

The options available for each subcommand are available in the Command Line
Reference or via the --help option.

Take a look at the [Getting Started
Guide](https://github.com/coreos/coreos-installer/blob/main/docs/getting-started.md)
for more information regarding how to download and use coreos-installer.

%prep
%autosetup -p 1 -a 1

%build
%{cargo_build} --features docgen,rdcore

PROFILE=release docs/_cmd.sh
PROFILE=release docs/_config-file.sh
./target/release/coreos-installer pack man -C man
./target/release/coreos-installer pack example-config >> example-config.yaml

%install
install -D -d -m 0755 %{buildroot}%{_bindir}
install -m 0755 %{_builddir}/%{name}-%{version}/target/release/%{name} %{buildroot}%{_bindir}/%{name}
install -D -d -m 0755 %{buildroot}%{_mandir}/man8/
for manpage in man/coreos-installer*
do
    install -m 0644 "${manpage}" %{buildroot}%{_mandir}/man8/
done

%check
%{cargo_test}

%files
%doc README.md example-config.yaml
%license LICENSE
%{_bindir}/%{name}
%{_mandir}/man8/coreos-installer*

%changelog
* Wed Apr 16 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.24.0:
  * cargo: coreos-installer release 0.24.0
  * docs/release-notes: update for release 0.24.0
  * cargo: update dependencies
  * Sync repo templates ⚙
  * build(deps): bump tokio from 1.43.0 to 1.44.2
  * build(deps): bump flate2 from 1.0.35 to 1.1.1
  * build(deps): bump openssl from 0.10.71 to 0.10.72
  * build(deps): bump nmstate from 2.2.41 to 2.2.43
  * build(deps): bump libc from 0.2.170 to 0.2.171
  * build(deps): bump tempfile from 3.19.0 to 3.19.1
  * build(deps): bump reqwest from 0.12.12 to 0.12.15
  * build(deps): bump serde from 1.0.218 to 1.0.219
  * build(deps): bump uuid from 1.14.0 to 1.16.0
  * build(deps): bump tempfile from 3.17.1 to 3.19.0
  * Sync repo templates ⚙
  * build(deps): bump textwrap from 0.16.1 to 0.16.2
  * build(deps): bump bytes from 1.10.0 to 1.10.1
  * build(deps): bump ring from 0.17.9 to 0.17.13
  * build(deps): bump thiserror from 2.0.11 to 2.0.12
  * build(deps): bump anyhow from 1.0.96 to 1.0.97
  * build(deps): bump serde_json from 1.0.139 to 1.0.140
  * Fix cargo clippy (warnings)
  * build(deps): bump nmstate from 2.2.39 to 2.2.41
  * workflows/rust: bump lints toolchain to 1.84.1
  * Cargo.toml: bump MSRV to 1.84.1
  * build(deps): bump libc from 0.2.169 to 0.2.170
  * build(deps): bump uuid from 1.13.1 to 1.14.0
  * build(deps): bump serde from 1.0.217 to 1.0.218
  * build(deps): bump anyhow from 1.0.95 to 1.0.96
  * build(deps): bump serde_json from 1.0.138 to 1.0.139
  * build(deps): bump zstd from 0.13.2 to 0.13.3
  * build(deps): bump tempfile from 3.17.0 to 3.17.1
  * cargo: require byte-unit 5.1.6 or greater
  * build(deps): bump byte-unit from 4.0.19 to 5.1.6
  * hash: remove deprecated funcion and add updated one
  * docs: re-gen manpages with clap_mangen 0.2.26
  * build(deps): bump nix from 0.27.1 to 0.29.0
  * build(deps): bump reqwest from 0.12.9 to 0.12.12
  * build(deps): bump serde_json from 1.0.133 to 1.0.138
  * build(deps): bump serde_with from 3.11.0 to 3.12.0
  * build(deps): bump rand from 0.8.5 to 0.9.0
  * build(deps): bump tempfile from 3.14.0 to 3.16.0
  * build(deps): bump uuid from 1.11.0 to 1.13.1
  * signing-keys: drop Fedora 40 key
  * signing-keys: add Fedora 43 key
  * s390x: remove 'sdboot' before generating new one
  * s390x: use more meaningfull long options for genprotimg
  * build(deps): bump clap_mangen from 0.2.24 to 0.2.26
  * build(deps): bump openssl from 0.10.68 to 0.10.70
  * build(deps): bump libc from 0.2.168 to 0.2.169
  * build(deps): bump anyhow from 1.0.94 to 1.0.95
  * build(deps): bump glob from 0.3.1 to 0.3.2
  * build(deps): bump serde from 1.0.215 to 1.0.217
  * build(deps): bump thiserror from 2.0.6 to 2.0.11
  * Sync repo templates ⚙
  * Sync repo templates ⚙
  * build(deps): bump libc from 0.2.164 to 0.2.168
  * build(deps): bump anyhow from 1.0.93 to 1.0.94
  * build(deps): bump thiserror from 1.0.69 to 2.0.6
  * build(deps): bump bytes from 1.8.0 to 1.9.0
  * dockerfile: update to `fedora:41`
  * build(deps): bump rustls from 0.23.16 to 0.23.18
  * build(deps): bump nmstate from 2.2.38 to 2.2.39
  * build(deps): bump url from 2.5.3 to 2.5.4
  * build(deps): bump actions/checkout from 3 to 4
  * Sync repo templates ⚙
  * build(deps): bump flate2 from 1.0.34 to 1.0.35
  * build(deps): bump libc from 0.2.162 to 0.2.164
  * build(deps): bump serde_json from 1.0.132 to 1.0.133
  * Sync repo templates ⚙
  * Sync repo templates ⚙
  * build(deps): bump serde_with from 3.9.0 to 3.11.0
* Wed Nov 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.23.0:
  * cargo: coreos-installer release 0.23.0
  * workflows/rust: add gpg package to list of rpms to install
  * docs/release-notes: update for release 0.23.0
  * cargo: update dependencies
  * build(deps): bump thiserror from 1.0.63 to 1.0.64
  * build(deps): bump serde_json from 1.0.127 to 1.0.128
  * build(deps): bump anyhow from 1.0.86 to 1.0.87
  * build(deps): bump serde from 1.0.209 to 1.0.210
  * Use blkid instead of lsblk to get disk info when udev is not
    present
  * build(deps): bump serde from 1.0.208 to 1.0.209
  * build(deps): bump reqwest from 0.12.5 to 0.12.7
  * build(deps): bump nmstate from 2.2.34 to 2.2.35
  * build(deps): bump serde_json from 1.0.125 to 1.0.127
  * build(deps): bump flate2 from 1.0.31 to 1.0.33
  * packit: drop CentOS packaging
  * build(deps): bump serde_json from 1.0.122 to 1.0.125
  * build(deps): bump serde from 1.0.204 to 1.0.208
  * build(deps): bump libc from 0.2.155 to 0.2.158
  * signing-keys: drop Fedora 39 key
  * signing-keys: add Fedora 42 key
  * build(deps): bump tempfile from 3.11.0 to 3.12.0
  * build(deps): bump tempfile from 3.10.1 to 3.11.0
  * build(deps): bump regex from 1.10.5 to 1.10.6
  * build(deps): bump flate2 from 1.0.30 to 1.0.31
  * build(deps): bump nmstate from 2.2.33 to 2.2.34
  * build(deps): bump serde_json from 1.0.120 to 1.0.122
  * build(deps): bump bytes from 1.6.1 to 1.7.1
  * build(deps): bump clap_mangen from 0.2.22 to 0.2.23
  * build(deps): bump ignition-config from 0.3.0 to 0.4.1
* Fri Jul 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.22.1:
  * cargo: coreos-installer release 0.22.1
  * docs/release-notes: update for release 0.22.1
  * cargo: update dependencies
  * packit: downstream_package_name is not inherited by packages
  * build(deps): bump base64 from 0.21.7 to 0.22.1
  * build(deps): bump cpio from 0.2.2 to 0.4.0
* Wed Jul 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.22.0:
  * cargo: coreos-installer release 0.22.0
  * docs/release-notes: update for release 0.22.0
  * cargo: update dependencies
  * packit.yaml: add c9s
  * build(deps): bump serde from 1.0.197 to 1.0.204
  * Sync repo templates ⚙
  * Dockerfile: rebase from f39 to f40
  * fixtures/customize/dest: update unit to use console.cfg
  * test/images/customize: add debug logic to give better feedback
  * */customize/*: shorten network interface names to 15 chars
  * rootmap: fix multipath + LUKS case
  * rootmap: correctly join paths when looking for physical root
  * Sync repo templates ⚙
  * build(deps): bump reqwest from 0.12.3 to 0.12.4
  * workflows/rust: bump lints toolchain to 1.77.2
  * build(deps): bump clap from 4.4.18 to 4.5.4
  * Cargo.toml: bump MSRV to 1.75.0
  * build(deps): bump uuid from 1.7.0 to 1.8.0
  * build(deps): bump serde_with from 3.6.1 to 3.7.0
  * build(deps): bump regex from 1.10.3 to 1.10.4
  * build(deps): bump bytes from 1.5.0 to 1.6.0
  * build(deps): bump thiserror from 1.0.57 to 1.0.58
  * build(deps): bump serde_json from 1.0.114 to 1.0.115
  * build(deps): bump reqwest from 0.11.24 to 0.12.3
  * build(deps): bump tempfile from 3.10.0 to 3.10.1
  * build(deps): bump h2 from 0.3.24 to 0.3.26
  * build(deps): bump nmstate from 2.2.25 to 2.2.27
  * build(deps): bump serde_yaml from 0.9.32 to 0.9.34+deprecated
  * build(deps): bump anyhow from 1.0.80 to 1.0.81
  * build(deps): bump mio from 0.8.10 to 0.8.11
  * packit: update dist_git_branches to target fedora-all
* Fri Apr 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package coreos-installer: Installer for the RedHat/Fedora
  CoreOS disk images
